#ifndef TAGS_H
#define TAGS_H

/*
 *  tags.h
 *  
 *
 *  Created by Alexander Thomas on 22/07/06.
 *
 *  Mind that this is mostly limited to functions I needed for id3gain, this is
 *  by far not a complete set of id3 editing tools.
 *
 */

/* TODO: turn this into a proper C++ class! */

#include <id3tag.h>


/* Create a new ID3 frame of the given type (must be a 4-byte identifier
 * like TALB, TXXX, ...)
 * The number of fields varies per type, unused fields must be passed as
 * NULL pointers. */
struct id3_frame * makeID3Frame( const char *type, const char *field1,
                                 const char *field2, const char *field3 );

/* Create a new binary ID3 frame of the given type */
struct id3_frame * makeID3BinaryFrame( const char *type, const id3_byte_t *data, id3_length_t length );

/* Set the contents of the given field, converting if necessary */
int setField( union id3_field *field, const char *contents );

/* Get the contents of the given field, converted to a latin1 string.
 * The returned pointer must be free'd. */
unsigned char * getField( union id3_field *field );

/* strcmp between id3_ucs4_t and char */
inline int id3_ucs4cmp( const id3_ucs4_t *ucs4String, const char *string );

/* Return the frame of the given type, with the string field at labelPos
 * matching the given label. */
struct id3_frame * findFrameWithLabel( struct id3_tag *fileTag, const char *type,
                                       const char *label, int labelPos );


/*-- TXXX frame functions --*/
/* Shortcut for findFrameWithLabel for a TXXX frame */
struct id3_frame * findTXXX( struct id3_tag *fileTag, const char *label );

/* Attach new frame (return value 0) or update existing frame (return value 1) */
int setTXXX( struct id3_tag *fileTag, const char *label, const char *contents );

/* Delete frame, if the frame is not present, return value is 0, otherwise 1 */
int deleteTXXX( struct id3_tag *fileTag, const char *label );

/*-- COMM frame functions --*/
/* Shortcut for findFrameWithLabel for a TXXX frame */
struct id3_frame * findCOMM( struct id3_tag *fileTag, const char *label );

/* Attach new frame (return value 0) or update existing frame (return value 1)
 * lang must be a 3-byte code. */
int setCOMM( struct id3_tag *fileTag, const char *lang, const char *label,
             const char *contents );

/* Delete frame, if the frame is not present, return value is 0, otherwise 1 */
int deleteCOMM( struct id3_tag *fileTag, const char *label );


/*-- Diagnostic functions --*/
/* Displays tag version, number of frames, and total size */
void tagInfo( const struct id3_tag *fileTag );

/* Displays some information about each frame in a tag */
void tagFramesInfo( const struct id3_tag *fileTag );


/*-- Utility functions --*/

/* Returns a duplicate of the given string.
 * The returned pointer must be free'd. */
unsigned char * dupString( const unsigned char *str );

#endif /* TAGS_H */
